bmscstan wrapper for diagnostics for Pareto smoothed importance sampling (PSIS)
BMSC_pareto_k_table(x)BMSC_pareto_k_ids(x, threshold = 0.5)
BMSC_mcse_loo(x, threshold = 0.7)
BMSC_pareto_k_values(x)
BMSC_pareto_k_influence_values(x)
BMSC_psis_n_eff_values(x)
# S3 method for pareto_k_table_BMSC
print(x, ...)
# S3 method for pareto_k_ids_BMSC
print(x, ...)
# S3 method for pareto_k_values_BMSC
print(x, ...)
# S3 method for pareto_k_influence_values_BMSC
print(x, ...)
# S3 method for psis_n_eff_values_BMSC
print(x, ...)
# S3 method for mcse_loo_BMSC
print(x, ...)
pareto_k_table returns an object of class "pareto_k_table_BMSC", which is a matrix with columns "Count", "Proportion", and "Min. n_eff"
pareto_k_ids returns an integer vector indicating which observations have Pareto k estimates above threshold
mcse_loo returns the Monte Carlo standard error (MCSE) estimate for PSIS-LOO. MCSE will be NA if any Pareto kk values are above threshold.
pareto_k_values returns a vector of the estimated Pareto k parameters. These represent the reliability of sampling.
pareto_k_influence_values returns a vector of the estimated Pareto k parameters. These represent influence of the observations on the model posterior distribution.
psis_k_influence_table returns a vector of the estimated PSIS effective sample sizes.
An object of class loo_BMSC
for the `pareto_k_ids` method is the minimum $k$ value to flag. for the `mcse_loo` method all the $k$ values greater than the `threshold` will be returned as NA.
further arguments passed to the `print` function.